pub struct StorageConfig {
pub state_file: String,
}Fields
state_file: StringPath to state file for persistence
Implementations
Sourceimpl StorageConfig
impl StorageConfig
Sourcepub fn get_default_state_file_path() -> String
pub fn get_default_state_file_path() -> String
Get the default state file path using XDG Base Directory specification Falls back to current directory if XDG data directory is not available
Sourcepub fn get_default_state_file_path_for_user(username: Option<&str>) -> String
pub fn get_default_state_file_path_for_user(username: Option<&str>) -> String
Get the default state file path for a specific user using XDG Base Directory specification Falls back to current directory if XDG data directory is not available
Sourcepub fn get_edit_log_path(state_file_path: &str) -> String
pub fn get_edit_log_path(state_file_path: &str) -> String
Get the edit log file path based on the state file path Uses the same directory as the state file but with a cleaner name