pub struct SettingsState {
pub require_confirmation: bool,
pub require_confirmation_for_edits: bool,
pub require_confirmation_for_new_rules: bool,
}Fields
require_confirmation: boolGlobal setting to require confirmation for all edits
require_confirmation_for_edits: boolGlobal setting to require confirmation for edit operations specifically
require_confirmation_for_new_rules: boolGlobal setting to require confirmation for new rule creation